@@ -2,6 +2,7 @@ from openpyxl import workbook
 from openpyxl import load_workbook
 from robot.api import logger
 from SeleniumLibrary.base import keyword, LibraryComponent
+from robot.libraries.BuiltIn import BuiltIn
 import json
 
 
@@ -25,4 +26,13 @@ class BDSExcelDriver:
             wb.create_sheet(sheet_name)
         sheet = wb[sheet_name]
         result = sheet[column + row].value
-        return result
\ No newline at end of file
+        return result
+        
+    @keyword
+    def _set_global_variable_from_existing_excel(self, name, column='A', row='1', sheet_name='Sheet1'):
+        wb = load_workbook(self.file)
+        if(wb.sheetnames.count(sheet_name) == 0):
+            wb.create_sheet(sheet_name)
+        sheet = wb[sheet_name]
+        result = sheet[column + row].value
+        BuiltIn().set_global_variable(name, result)
